@@ -194,7 +194,7 @@ class AsyncKafkaSubscriber(AsyncSubscriber):
         """
         meta = self._task_meta.pop(task.uuid, None)
         if not meta:
-            self.logger.error(f"no metadata for given task {task}")
+            self.logger.error(f"no metadata for given task '{task.task_type} (uuid={task.uuid})'")
             raise KeyError()
 
         tp = TopicPartition(meta[0], meta[1])
